@@ -4,7 +4,7 @@ use true;
 use experimental qw( signatures );
 use stable qw( postderef );
 
-package Data::Section::Pluggable 0.04 {
+package Data::Section::Pluggable 0.05 {
 
     # ABSTRACT: Read structured data from __DATA__
 
@@ -13,7 +13,7 @@ package Data::Section::Pluggable 0.04 {
     use Exporter qw( import );
     use Ref::Util qw( is_ref is_plain_hashref is_coderef is_plain_arrayref );
     use MIME::Base64 qw( decode_base64 );
-    use Path::Tiny ();
+    use Path::Tiny 0.130 ();
     use Carp ();
 
     our @EXPORT_OK = qw( get_data_section );
@@ -210,7 +210,7 @@ Data::Section::Pluggable - Read structured data from __DATA__
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
